@@ -94,8 +94,8 @@ class Link:
             "namespace": "",
         },
     )
-    pose: "Link.Pose" = field(
-        default="0 0 0 0 0 0",
+    pose: Optional["Link.Pose"] = field(
+        default=None,
         metadata={
             "type": "Element",
             "namespace": "",
@@ -207,8 +207,8 @@ class Link:
             defined inside the parent that this frame is attached to.
         """
 
-        pose: "Link.Frame.Pose" = field(
-            default="0 0 0 0 0 0",
+        pose: Optional["Link.Frame.Pose"] = field(
+            default=None,
             metadata={
                 "type": "Element",
                 "namespace": "",
@@ -233,7 +233,7 @@ class Link:
             """
 
             value: str = field(
-                default="",
+                default="0 0 0 0 0 0",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -256,7 +256,7 @@ class Link:
         """
 
         value: str = field(
-            default="",
+            default="0 0 0 0 0 0",
             metadata={
                 "required": True,
                 "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -311,8 +311,8 @@ class Link:
                 "namespace": "",
             },
         )
-        pose: "Link.Inertial.Pose" = field(
-            default="0 0 0 0 0 0",
+        pose: Optional["Link.Inertial.Pose"] = field(
+            default=None,
             metadata={
                 "type": "Element",
                 "namespace": "",
@@ -392,8 +392,8 @@ class Link:
                 attached to.
             """
 
-            pose: "Link.Inertial.Frame.Pose" = field(
-                default="0 0 0 0 0 0",
+            pose: Optional["Link.Inertial.Frame.Pose"] = field(
+                default=None,
                 metadata={
                     "type": "Element",
                     "namespace": "",
@@ -419,7 +419,7 @@ class Link:
                 """
 
                 value: str = field(
-                    default="",
+                    default="0 0 0 0 0 0",
                     metadata={
                         "required": True,
                         "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -442,7 +442,7 @@ class Link:
             """
 
             value: str = field(
-                default="",
+                default="0 0 0 0 0 0",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -511,8 +511,8 @@ class Link:
                 "namespace": "",
             },
         )
-        pose: "Link.Projector.Pose" = field(
-            default="0 0 0 0 0 0",
+        pose: Optional["Link.Projector.Pose"] = field(
+            default=None,
             metadata={
                 "type": "Element",
                 "namespace": "",
@@ -548,8 +548,8 @@ class Link:
                 attached to.
             """
 
-            pose: "Link.Projector.Frame.Pose" = field(
-                default="0 0 0 0 0 0",
+            pose: Optional["Link.Projector.Frame.Pose"] = field(
+                default=None,
                 metadata={
                     "type": "Element",
                     "namespace": "",
@@ -575,7 +575,7 @@ class Link:
                 """
 
                 value: str = field(
-                    default="",
+                    default="0 0 0 0 0 0",
                     metadata={
                         "required": True,
                         "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -598,7 +598,7 @@ class Link:
             """
 
             value: str = field(
-                default="",
+                default="0 0 0 0 0 0",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -715,8 +715,8 @@ class Link:
                 "namespace": "",
             },
         )
-        pose: "Link.AudioSource.Pose" = field(
-            default="0 0 0 0 0 0",
+        pose: Optional["Link.AudioSource.Pose"] = field(
+            default=None,
             metadata={
                 "type": "Element",
                 "namespace": "",
@@ -758,8 +758,8 @@ class Link:
                 attached to.
             """
 
-            pose: "Link.AudioSource.Frame.Pose" = field(
-                default="0 0 0 0 0 0",
+            pose: Optional["Link.AudioSource.Frame.Pose"] = field(
+                default=None,
                 metadata={
                     "type": "Element",
                     "namespace": "",
@@ -785,7 +785,7 @@ class Link:
                 """
 
                 value: str = field(
-                    default="",
+                    default="0 0 0 0 0 0",
                     metadata={
                         "required": True,
                         "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -808,7 +808,7 @@ class Link:
             """
 
             value: str = field(
-                default="",
+                default="0 0 0 0 0 0",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
